/*
This file is part of Ext JS 3.4

Copyright (c) 2011-2013 Sencha Inc

Contact:  http://www.sencha.com/contact

GNU General Public License Usage
This file may be used under the terms of the GNU General Public License version 3.0 as
published by the Free Software Foundation and appearing in the file LICENSE included in the
packaging of this file.

Please review the following information to ensure the GNU General Public License version 3.0
requirements will be met: http://www.gnu.org/copyleft/gpl.html.

If you are unsure which license is appropriate for your use, please contact the sales department
at http://www.sencha.com/contact.

Build date: 2013-04-03 15:07:25
*/
.ext-el-mask {
    z-index: 100;
    position: absolute;
    top:0;
    left:0;
    -moz-opacity: 0.5;
    opacity: .50;
    filter: alpha(opacity=50);
    width: 100%;
    height: 100%;
    zoom: 1;
}

.ext-el-mask-msg {
    z-index: 20001;
    position: absolute;
    top: 0;
    left: 0;
    border:1px solid;
    background:repeat-x 0 -16px;
    padding:2px;
}

.ext-el-mask-msg div {
    padding:5px 10px 5px 10px;
    border:1px solid;
    cursor:wait;
}

.ext-shim {
    position:absolute;
    visibility:hidden;
    left:0;
    top:0;
    overflow:hidden;
}

.ext-ie .ext-shim {
    filter: alpha(opacity=0);
}

.ext-ie6 .ext-shim {
    margin-left: 5px;
    margin-top: 3px;
}

.x-mask-loading div {
    padding:5px 10px 5px 25px;
    background:no-repeat 5px 5px;
    line-height:16px;
}

/* class for hiding elements without using display:none */
.x-hidden, .x-hide-offsets {
    position:absolute !important;
    left:-10000px;
    top:-10000px;
    visibility:hidden;
}

.x-hide-display {
    display:none !important;
}

.x-hide-nosize,
.x-hide-nosize *    /* Emulate display:none for children */
 {
   height:0px!important;
   width:0px!important;
   visibility:hidden!important;
   border:none!important;
   zoom:1;
}

.x-hide-visibility {
    visibility:hidden !important;
}

.x-masked {
    overflow: hidden !important;
}
.x-masked-relative {
    position: relative !important;
}

.x-masked select, .x-masked object, .x-masked embed {
    visibility: hidden;
}

.x-layer {
    visibility: hidden;
}

.x-unselectable, .x-unselectable * {
    user-select: none;
    -o-user-select: none;
    -ms-user-select: none;
    -moz-user-select: -moz-none;
    -webkit-user-select: none;
    
    cursor:default;
}

.x-repaint {
    zoom: 1;
    background-color: transparent;
    -moz-outline: none;
    outline: none;
}

.x-item-disabled {
    cursor: default;
    opacity: .6;
    -moz-opacity: .6;
    filter: alpha(opacity=60);
}

.x-item-disabled * {
    cursor: default !important;
}

.x-form-radio-group .x-item-disabled {
    filter: none;
}

.x-splitbar-proxy {
    position: absolute;
    visibility: hidden;
    z-index: 20001;
    zoom: 1;
    line-height: 1px;
    font-size: 1px;
    overflow: hidden;
}

.x-splitbar-h, .x-splitbar-proxy-h {
    cursor: e-resize;
    cursor: col-resize;
}

.x-splitbar-v, .x-splitbar-proxy-v {
    cursor: s-resize;
    cursor: row-resize;
}

.x-color-palette {
    width: 150px;
    height: 92px;
    cursor: pointer;
}

.x-color-palette a {
    border: 1px solid;
    float: left;
    padding: 2px;
    text-decoration: none;
    -moz-outline: 0 none;
    outline: 0 none;
    cursor: pointer;
}

.x-color-palette a:hover, .x-color-palette a.x-color-palette-sel {
    border: 1px solid;
}

.x-color-palette em {
    display: block;
    border: 1px solid;
}

.x-color-palette em span {
    cursor: pointer;
    display: block;
    height: 10px;
    line-height: 10px;
    width: 10px;
}

.x-ie-shadow {
    display: none;
    position: absolute;
    overflow: hidden;
    left:0;
    top:0;
    zoom:1;
}

.x-shadow {
    display: none;
    position: absolute;
    overflow: hidden;
    left:0;
    top:0;
}

.x-shadow * {
    overflow: hidden;
}

.x-shadow * {
    padding: 0;
    border: 0;
    margin: 0;
    clear: none;
    zoom: 1;
}

/* top  bottom */
.x-shadow .xstc, .x-shadow .xsbc {
    height: 6px;
    float: left;
}

/* corners */
.x-shadow .xstl, .x-shadow .xstr, .x-shadow .xsbl, .x-shadow .xsbr {
    width: 6px;
    height: 6px;
    float: left;
}

/* sides */
.x-shadow .xsc {
    width: 100%;
}

.x-shadow .xsml, .x-shadow .xsmr {
    width: 6px;
    float: left;
    height: 100%;
}

.x-shadow .xsmc {
    float: left;
    height: 100%;
    background-color: transparent;
}

.x-shadow .xst, .x-shadow .xsb {
    height: 6px;
    overflow: hidden;
    width: 100%;
}

.x-shadow .xsml {
    background: transparent repeat-y 0 0;
}

.x-shadow .xsmr {
    background: transparent repeat-y -6px 0;
}

.x-shadow .xstl {
    background: transparent no-repeat 0 0;
}

.x-shadow .xstc {
    background: transparent repeat-x 0 -30px;
}

.x-shadow .xstr {
    background: transparent repeat-x 0 -18px;
}

.x-shadow .xsbl {
    background: transparent no-repeat 0 -12px;
}

.x-shadow .xsbc {
    background: transparent repeat-x 0 -36px;
}

.x-shadow .xsbr {
    background: transparent repeat-x 0 -6px;
}

.loading-indicator {
    background: no-repeat left;
    padding-left: 20px;
    line-height: 16px;
    margin: 3px;
}

.x-text-resize {
    position: absolute;
    left: -1000px;
    top: -1000px;
    visibility: hidden;
    zoom: 1;
}

.x-drag-overlay {
    width: 100%;
    height: 100%;
    display: none;
    position: absolute;
    left: 0;
    top: 0;
    background-image:url(../images/default/s.gif);
    z-index: 20000;
}

.x-clear {
    clear:both;
    height:0;
    overflow:hidden;
    line-height:0;
    font-size:0;
}

.x-spotlight {
    z-index: 8999;
    position: absolute;
    top:0;
    left:0;
    -moz-opacity: 0.5;
    opacity: .50;
    filter: alpha(opacity=50);
    width:0;
    height:0;
    zoom: 1;
}

#x-history-frame {
    position:absolute;
    top:-1px;
    left:0;
	width:1px;
    height:1px;
    visibility:hidden;
}

#x-history-field {
    position:absolute;
    top:0;
    left:-1px;
	width:1px;
    height:1px;
    visibility:hidden;
}
